function [res]=test3(serie)
%function [res]=test3(serie)
% Approximation mit "robuster Gradienten-Methode"
% serie = Nummer der Verifikationsmessung.
% res[1]  : berechneter ed50-Wert
% res[2]  : berechneter ed95-Wert
% res[3]  : Summe der Residuen^2
% res[4,5]: Parameter a und b 
% res[6]  : Anzahl Iterationen

% Lade die Daten der Verifikationsmessungen
load data

% Konzentration des Fungizids in [mg/l]
x=[0.0001,0.0003,0.001,0.003,0.01,0.03,0.1,0.3,1,10]';

% Hemmung aus den Daten bestimmen 
y= data(10*serie-9:10*serie,2)/100;

% Werte um 0 sind nicht gut...
for i=1:10,
  if abs(y(i)) <0.0001,
    y(i) = 0.0001;
  end
end

A= [ones(size(x)),log(x)];

% Startwert ermitteln
[a,b]=startwert(0,10,0,2,x,y);
koeff=[a;b];   
% input('press any key);   % Zur Kontrolle

% Sigmoid-Funktion zur Kontrolle des Anfangswerts plotten
% ys = 1 ./ (1+exp(-A*koeff));
% semilogx(x,ys,x,y,'o',x,y);

% "Fehlerlandschaft" plotten
% a= linspace(9.6,10,20);
% b= linspace(1.8,2.2,20);
% for ai= 1:length(a),
%   for bi=1:length(b),
%     ys = 1 ./ (1+exp(-(a(ai)+b(bi)*log(x)))); 
%     z(ai,bi)=norm(ys-y);
%  end;
% end;
% mesh(b,a,z)
% input('press any key');

Nmin=1000;

iter = 0;
TotMin = 1000;
alp=1;
while iter<200,
 iter=iter+1;

 % Beste Richtung bestimmen. Dazu in 64 Richtungen den
 % Funktionswert bestimmen bei Radius = 1
  Nmin=1000;
  for ang=0:pi/32:2*pi,
    vec=[cos(ang); sin(ang)];
    h = exp(-A*(koeff+vec));  % Hilfsvariable
    n=norm(1./(1+h)-y);
    if n < Nmin,
      Nmin=n;
      grad=vec;
    end
  end

  % In der besten Richtung das Minimum finden. Dazu Kurve mit
  % einem Polynom 2. Grades annaehern und das Minimum bestimmen.  
  grad=-grad;

  h = exp(-A*(koeff-0*grad));   % Hilfsvariable
  g1= norm(1./ (1+h)-y)^2;   % sum(residuen)bei alpha = 0

  h = exp(-A*(koeff-alp*grad));   % Hilfsvariable
  g2= norm(1./ (1+h)-y)^2;   % sum(residuen) bei alpha = 1

  h = exp(-A*(koeff-0.5*alp*grad)); % Hilfsvariable
  g3= norm(1./ (1+h)-y)^2;   % sum(residuen) bei alpha = 0.5
  h1 =2*(g2 - g1)/alp;
  h2 =2*(g3 - g2)/alp;
  h3 =(h2-h1)/alp;

  % a0 ist die Entfernung, wie weit man in der besten
  % Richtung gehen muss, bis man auf das Minimum trifft.
  a0=(alp*0.5*h3-h1)/(2*h3);

  koeff = koeff - a0*grad;
  h = exp(-A*koeff);  % Hilfsvariable
  no(iter)= norm(1./ (1+h)-y)^2;    % sum(residuen) bei optimalem alpha
  
  if no(iter) < TotMin,
    TotMin=no(iter);
    Kmin=koeff;
  end
  
  k(:,iter)=koeff;

  % Abbruchkriterium
  if iter > 5000,
    if (max(no(iter-5:iter))-min(no(iter-5:iter))) < 0.03*no(iter),
      break
    end
  end
end

%ED50 und ED95-Werte berechnen
ed50=exp(-Kmin(1)/Kmin(2));  % = 0.0183233
ed95=exp((-log(0.05/0.95)-Kmin(1))/Kmin(2));

res(1)=ed50; res(2)=ed95; res(3)=Nmin; res(4:5)=Kmin; res(6)=iter;

% Kontroll-Plots
%plot(n)              % Verlauf der norm
%contour(b,a,z,50)    % Fehlerlandschaft von oben
%hold on
%plot(k(2,:),k(1,:))  % Verlauf der Koeff in der Fehlerlandschaft 
%hold off

% Zur Kontrolle noch Messpunkte und Kurve aufzeichnen
%x1=logspace(-4,1,100);
%y1 = 1 ./ (1+exp(-Kmin(1)-Kmin(2)*log(x1)));
%semilogx(x1,y1,x,y,x,y,'o')
